==> shieldb-0.2.1-py3-none-any.whl: application/core/parser_data.py <==
import argparse
import os
from sqlalchemy import create_engine, text
from sqlalchemy.exc import SQLAlchemyError


def connection_db():
    try:
        print(os.environ.get('SQLALCHEMY_DATABASE_URI'), "test")
        db_url = os.environ.get('SQLALCHEMY_DATABASE_URI', 'postgresql://postgres:12345@localhost:5433/masking_test_db')
        engine = create_engine(db_url)
        conn = engine.connect()
        return conn
    except SQLAlchemyError as e:
        return None


def get_all_columns_by_query(table_name, connection):
    result = connection.execute(text(
        f"SELECT column_name FROM information_schema.columns WHERE table_name = '{table_name}' AND column_name <> 'id'"
    ))
    return [row[0] for row in result]


def parse_data():
    parser = argparse.ArgumentParser(description='Script for deleting or masking data from a database\nIn order for '
                                                 'the project to work, you need to set the db to work with in the '
                                                 'first stage.')
    parser.add_argument('--action', choices=['delete', 'mask'], help='Operation to be performed')
    parser.add_argument('--table', help='Name of the table from which data will be deleted or masked')
    parser.add_argument('--percentage', type=float, default=0, help='Percentage of data to be deleted (default: 0)')
    parser.add_argument('--columns', nargs='+', default=[], help='Columns to be masked')
    parser.add_argument('--run_mode', default=None)

    command_line_args = parser.parse_args()
    connection = connection_db()
    return command_line_args, connection

==> shieldb-0.2.4-py3-none-any.whl: application/core/parser_data.py <==
import argparse
import os
from sqlalchemy import create_engine, text
from sqlalchemy.exc import SQLAlchemyError


def connection_db():
    try:
        print(os.environ.get('SQLALCHEMY_DATABASE_URI'), "test")
        db_url = os.environ.get('SQLALCHEMY_DATABASE_URI', 'postgresql://postgres:12345@localhost:5433/masking_test_db')
        engine = create_engine(db_url)
        conn = engine.connect()
        return conn
    except SQLAlchemyError as e:
        return None


def get_table_columns(table_name, connection):
    result = connection.execute(text(
        f"SELECT column_name FROM information_schema.columns WHERE table_name = '{table_name}' AND column_name <> 'id'"
    ).params(table=table_name))

    return [row[0] for row in result]


def init_data_processing():
    parser = argparse.ArgumentParser(description='Script for deleting or masking data from a database\nIn order for '
                                                 'the project to work, you need to set the db to work with in the '
                                                 'first stage. The variable you need to set should be SQLALCHEMY_DATABASE_URI')
    parser.add_argument('--action', choices=['delete', 'mask'], help='Operation to be performed')
    parser.add_argument('--table', help='Name of the table from which data will be deleted or masked')
    parser.add_argument('--percentage', type=float, default=0, help='Percentage of data to be deleted (default: 0), PERCENTAGE SHOULD BE BETWEEN 0 AND 100.')
    parser.add_argument('--columns', nargs='+', default=[], help='The columns to be masked will be entered with spaces.')

    command_line_args = parser.parse_args()
    connection = connection_db()
    return command_line_args, connection
